@@ -5,23 +5,28 @@ from .widget import Widget, CallbackDispatcher, register, widget_serialization
 from .domwidget import DOMWidget
 from .valuewidget import ValueWidget
 
-from .trait_types import Color, Datetime, NumberFormat
+from .trait_types import Color, Datetime, NumberFormat, TypedTuple
 
 from .widget_core import CoreWidget
 from .widget_bool import Checkbox, ToggleButton, Valid
 from .widget_button import Button, ButtonStyle
-from .widget_box import Box, HBox, VBox
+from .widget_box import Box, HBox, VBox, GridBox
 from .widget_float import FloatText, BoundedFloatText, FloatSlider, FloatProgress, FloatRangeSlider, FloatLogSlider
-from .widget_image import Image
 from .widget_int import IntText, BoundedIntText, IntSlider, IntProgress, IntRangeSlider, Play, SliderStyle
 from .widget_color import ColorPicker
 from .widget_date import DatePicker
+from .widget_datetime import DatetimePicker
+from .widget_time import TimePicker
 from .widget_output import Output
 from .widget_selection import RadioButtons, ToggleButtons, ToggleButtonsStyle, Dropdown, Select, SelectionSlider, SelectMultiple, SelectionRangeSlider
-from .widget_selectioncontainer import Tab, Accordion
-from .widget_string import HTML, HTMLMath, Label, Text, Textarea, Password
+from .widget_selectioncontainer import Tab, Accordion, Stack
+from .widget_string import HTML, HTMLMath, Label, Text, Textarea, Password, Combobox
 from .widget_controller import Controller
 from .interaction import interact, interactive, fixed, interact_manual, interactive_output
 from .widget_link import jslink, jsdlink
 from .widget_layout import Layout
+from .widget_media import Image, Video, Audio
+from .widget_tagsinput import TagsInput, ColorsInput, FloatsInput, IntsInput
 from .widget_style import Style
+from .widget_templates import TwoByTwoLayout, AppLayout, GridspecLayout
+from .widget_upload import FileUpload
