@@ -2,10 +2,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 import pytest
-try:
-    from unittest import mock
-except ImportError:
-    import mock
+from unittest import mock
 
 from traitlets import Bool, Tuple, List, Instance, CFloat, CInt, Float, Int, TraitError, observe
 
@@ -265,7 +262,6 @@ def test_property_lock(echo):
     calls = []
     widget._send.assert_has_calls(calls)
 
-
 def test_hold_sync(echo):
     # when this widget's value is set to 42, it sets the value to 2, and also sets a different trait value
     class AnnoyingWidget(Widget):
@@ -276,9 +272,8 @@ def test_hold_sync(echo):
         def _propagate_value(self, change):
             print('_propagate_value', change.new)
             if change.new == 42:
-                with self.hold_sync():
-                    self.value = 2
-                    self.other = 11
+                self.value = 2
+                self.other = 11
 
     widget = AnnoyingWidget(value=1)
     assert widget.value == 1
@@ -299,8 +294,9 @@ def test_hold_sync(echo):
     widget._send.assert_has_calls(calls)
 
 
-def test_echo(echo):
-    # we always echo values back to the frontend if configured
+
+def test_echo():
+    # we always echo values back to the frontend
     class ValueWidget(Widget):
         value = Float().tag(sync=True)
 
@@ -316,12 +312,11 @@ def test_echo(echo):
     msg = {'method': 'echo_update', 'state': {'value': 42.0}, 'buffer_paths': []}
     call42 = mock.call(msg, buffers=[])
 
-    calls = [call42] if echo else []
+    calls = [call42]
     widget._send.assert_has_calls(calls)
 
 
-
-def test_echo_single(echo):
+def test_echo_single():
     # we always echo multiple changes back in 1 update
     class ValueWidget(Widget):
         value = Float().tag(sync=True)
@@ -357,7 +352,7 @@ def test_echo_single(echo):
     call2 = mock.call(msg, buffers=[])
 
 
-    calls = [call, call2] if echo else [call2]
+    calls = [call, call2]
     widget._send.assert_has_calls(calls)
 
 
@@ -389,6 +384,3 @@ def test_no_echo(echo):
     # a regular set should sync to the frontend
     widget.value = 43
     widget._send.assert_has_calls([mock.call({'method': 'update', 'state': {'value': 43.0}, 'buffer_paths': []}, buffers=[])])
-
-
-
